@@ -332,10 +332,12 @@ def get_suite_section_id(tr: TestRailAPI, project_id: int, project_suite_id: int
         }
         tr_suite_section = tr.sections.add_section(project_id=project_id, section=Section(suite_section))
         tr_suite_section_id = tr_suite_section.id
+        tr_suite_sections = tr.sections.get_sections(project_id, project_suite_id)
     if (sub_section_name_raw is not None and any(tr_suite_section.name == sub_section_name_raw
                                                  for tr_suite_section in tr_suite_sections)):
         print(f'Collecting Sub-Sections for suite {suite_name_raw} from TestRail')
-        tr_suite_sub_section_id = next(section.id for section in tr_suite_sections if section.name == section_name_raw)
+        tr_suite_sub_section_id = next(section.id
+                                       for section in tr_suite_sections if section.name == sub_section_name_raw)
         tr_suite_sub_section_id = tr_suite_sub_section_id
     elif sub_section_name_raw is not None:
         suite_sub_section = {
@@ -363,25 +365,31 @@ def export_tests_results(tr: TestRailAPI, project_data: dict, scenarios_run: lis
     feature_names = scenarios_run.keys()
 
     for feature_name in feature_names:
-        if feature_name not in plan_entry_names or (feature_name in plan_entry_names and project_data['configuration_name'] not in [run.config for run in functools.reduce(operator.iconcat, [plan_entry.runs for plan_entry in tr_plan.entries if plan_entry.name == feature_name])]):
-            print(f"Adding suite {feature_name} to test plan {tr_plan.name}")
-            suite_id = next((tr_suite.id for tr_suite in tr.suites.get_suites(project_data['project_id'])
-                             if tr_suite.name == feature_name), None)
+        if feature_name not in plan_entry_names:
+            config_ids = [config['id'] for config in functools.reduce(operator.iconcat,
+                                                                      [config_groups['configs'] for config_groups in
+                                                                       tr.configurations.get_configs(
+                                                                           project_data['project_id'])])]
+        else:
             config_ids = [config['id'] for config in functools.reduce(operator.iconcat,
                                                                       [config_groups['configs'] for config_groups in
                                                                        tr.configurations.get_configs(
                                                                            project_data['project_id'])])
                           if config['name'] == project_data['configuration_name']]
-            run = Run({
+        if feature_name not in plan_entry_names or (feature_name in plan_entry_names and project_data['configuration_name'] not in [run.config for run in functools.reduce(operator.iconcat, [plan_entry.runs for plan_entry in tr_plan.entries if plan_entry.name == feature_name])]):
+            print(f"Adding suite {feature_name} to test plan {tr_plan.name}")
+            suite_id = next((tr_suite.id for tr_suite in tr.suites.get_suites(project_data['project_id'])
+                             if tr_suite.name == feature_name), None)
+            runs = [Run({
                 'include_all': True,
-                'config_ids': config_ids,
-            }).raw_data()
+                'config_ids': [config_id],
+            }).raw_data() for config_id in config_ids]
             tr_plan_entry = Entry({
                 'suite_id': suite_id,
                 'name': feature_name,
                 'include_all': True,
                 'config_ids': config_ids,
-                'runs': [run]
+                'runs': runs
             })
             tr.plans.add_plan_entry(tr_plan.id, tr_plan_entry)
 
